import 'dart:async';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ongbut_ntmanh/app/module/course/model/list_data.dart';

import '../../const/colors.dart';
import '../../res/images/images.dart';
import '../module/comment/model/comment_model.dart';
import '../module/course/bloc/course_bloc.dart';
import '../module/course/model/course_model.dart';
import '../module/coursedetail/widgets/course_detail.dart';

final scrollController = ScrollController();
class SearchWidget extends StatelessWidget {
  SearchWidget({Key? key}) : super(key: key);
  CourseModel? courseModel;
  List<ListData> listData = [];
  @override
  Widget build(BuildContext context) {
    BlocProvider.of<CourseBloc>(context).add(
        RequestCourse(context: context));
    return
      Scaffold(
        appBar: AppBar(title: Text('asdsad'),),
        body:
        BlocBuilder<CourseBloc, CourseState>(
          builder: (context, state) {
            if(state is CourseInitial){
              const CircularProgressIndicator();
            }
            if(state is CourseLoading){
              return const CircularProgressIndicator();
            }
            if(state is CourseFailed){
              return Text(state.message.toString());
            }
            if(state is CourseSuccess){
              listData = state.courseModel.data!.listData!;
              return
                CustomScrollView(
                  scrollDirection: Axis.vertical,// listview vuot ngang
                  slivers:<Widget>[
                    SliverGrid(
                      gridDelegate: const SliverGridDelegateWithMaxCrossAxisExtent(
                        maxCrossAxisExtent: 300,
                        mainAxisSpacing: 1,
                        crossAxisSpacing: 0,
                        childAspectRatio: 1,
                      ),
                      delegate: SliverChildBuilderDelegate(
                            (BuildContext context, int index) {
                          if (index < listData.length) {
                            return _courseList(listData[index], context);
                          } else {
                            Timer(const Duration(milliseconds: 20), () {
                              scrollController
                                  .jumpTo(scrollController.position.maxScrollExtent);
                            });
                            return const CircularProgressIndicator();
                          }
                        },
                        childCount: listData.length,
                      ),
                    ),
                  ],
                );
            }
            return const Text('CourseFailed');
          }
      ),);

  }
}

Widget _courseList( listData, BuildContext context) {
  return InkWell(
    onTap: (){
      Navigator.push(
          context,
          MaterialPageRoute(
            builder: (_) => CourseDetailWidget(listData.courseId!,listData.image!=null?listData.image!:'https://oss.myitsol.com/imes-public/2022/12/11/neymar_145527553.PNG'),
          )).then((value) {
        if (value != null && value is bool && value) {}
      });
    },
    child: Padding(
      padding: const EdgeInsets.fromLTRB(15, 10, 15, 10),
      child:
      Container(
        decoration: BoxDecoration(borderRadius: BorderRadius.circular(10),
            color: AppColors.white),
        child: Column(
          children: <Widget>[
            ClipRRect(
              borderRadius: BorderRadius.circular(8.0),
              child:
              Image.network(listData.image!=null?listData.image!:'https://oss.myitsol.com/imes-public/2022/12/11/neymar_145527553.PNG',
                fit: BoxFit.fill,height: 120,width: double.maxFinite,),
            ),
            Text(listData.keyword!=null?listData.keyword:'Null'),
            Text(listData.name!=null?listData.name:'Null'),
          ],
        ),
      ),
    ),
  );
}
